@@ -7,19 +7,15 @@ use warnings;
 
 use 5.006;
 
-use vars (qw($VERSION $Tolerance $Min_samples_number));
+use vars (qw($Tolerance $Min_samples_number));
 
-$VERSION = '3.0611';
+our $VERSION = '3.0613';
 
 $Tolerance = 0.0;
 $Min_samples_number = 4;
 
 package Statistics::Descriptive::Sparse;
 
-use vars qw($VERSION);
-
-$VERSION = '3.0611';
-
 use vars qw(%fields);
 use Carp;
 use Statistics::Descriptive::Smoother;
@@ -236,10 +232,6 @@ sub clear {
 
 package Statistics::Descriptive::Full;
 
-use vars qw($VERSION);
-
-$VERSION = '3.0611';
-
 use Carp;
 use POSIX ();
 use Statistics::Descriptive::Smoother;
@@ -1038,18 +1030,27 @@ package Statistics::Descriptive;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Statistics::Descriptive - Module of basic descriptive statistical functions.
 
+=head1 VERSION
+
+version 3.0613
+
 =head1 SYNOPSIS
 
-  use Statistics::Descriptive;
-  $stat = Statistics::Descriptive::Full->new();
-  $stat->add_data(1,2,3,4); $mean = $stat->mean();
-  $var  = $stat->variance();
-  $tm   = $stat->trimmed_mean(.25);
-  $Statistics::Descriptive::Tolerance = 1e-10;
+    use Statistics::Descriptive;
+    my $stat = Statistics::Descriptive::Full->new();
+    $stat->add_data(1,2,3,4);
+    my $mean = $stat->mean();
+    my $var = $stat->variance();
+    my $tm = $stat->trimmed_mean(.25);
+    $Statistics::Descriptive::Tolerance = 1e-10;
 
 =head1 DESCRIPTION
 
@@ -1069,6 +1070,10 @@ of very small denominators.
 Many of the methods (both Sparse and Full) cache values so that subsequent
 calls with the same arguments are faster.
 
+=head1 VERSION
+
+version 3.0613
+
 =head1 METHODS
 
 =head2 Sparse Methods
@@ -1285,7 +1290,6 @@ This is consistent with Excel.
 Returns the kurtosis of the data.
 Positive is peaked, negative is flattened.
 
-
 =item $x = $stat->percentile(25);
 
 =item ($x, $index) = $stat->percentile(25);
@@ -1368,7 +1372,6 @@ Exemple :
   print $stat->quantile(3); # => 7.75
   print $stat->quantile(4); # => 10
 
-
 =item $stat->median();
 
 Sorts the data and returns the median value of the data.
@@ -1564,4 +1567,131 @@ and/or modify it under the same terms as Perl itself.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1997 by Jason Kastner, Andrea Spinelli, Colin Kuskie, and others.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Statistics-Descriptive/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Statistics::Descriptive
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Statistics-Descriptive>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Statistics-Descriptive>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Statistics-Descriptive>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Statistics-Descriptive>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Statistics-Descriptive>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Statistics-Descriptive>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/S/Statistics-Descriptive>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Statistics-Descriptive>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Statistics::Descriptive>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-statistics-descriptive at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Statistics-Descriptive>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/perl-Statistics-Descriptive>
+
+  git clone git://github.com/shlomif/perl-Statistics-Descriptive.git
+
 =cut
